Package: lcmsPlot
Type: Package
Title: Comprehensive Liquid Chromatography-Mass Spectrometry (LC-MS)
        data visualisation package
Version: 1.1.3
Authors@R: c(
    person(
        "Ossama",
        "Edbali",
        role=c("aut","cre"),
        email="o.edbali@bham.ac.uk",
        comment = c(ORCID = "0000-0003-0132-8668")),
    person(
        c("Ralf","Johannes", "Maria"),
        "Weber",
        role=c("aut"),
        email="r.j.weber@bham.ac.uk",
        comment = c(ORCID = "0000-0002-8796-4771")))
Description: lcmsPlot is an R package designed for visualising
    Liquid Chromatography-Mass Spectrometry (LC-MS) data with
    publication-ready high-quality plots.
    The package enables users to generate and customise chromatograms,
    mass traces, spectra, and more with fine-tuned aesthetics
    and annotation options.
License: GPL-3
Encoding: UTF-8
Depends: R (>= 4.4.0)
Imports: methods, rlang, dplyr, tibble, tidyr, BiocParallel, MSnbase,
        xcms, MsExperiment, mzR, Spectra, MsBackendMsp, S4Vectors,
        ggplot2, scales, patchwork, DBI, RSQLite
Suggests: knitr, rmarkdown, BiocStyle, openxlsx, faahKO, rawrr,
        msPurity, ggnewscale, htmltools, shiny, shinytoastr,
        shinytest2, testthat (>= 3.0.0)
Collate: 'lcmsPlot-package.R' 'zzz.R' 'helpers-data.R' 'helpers-s4.R'
        'raw-file-reader.R' 'xcms-raw-list.R' 'options.R'
        'processing-xcms.R' 'data-source.R'
        'data-source-compound-discoverer.R' 'data-source-mzmine.R'
        'data-source-ms-dial.R' 'creators-purity.R'
        'constructors-chromatograms.R' 'constructors-spectra.R'
        'data-validation.R' 'data-adapters.R' 'plot-units.R'
        'plot-chromatogram.R' 'plot-mass-trace.R' 'plot-spectrum.R'
        'plot-total-ion-current.R' 'plot-intensity-map.R'
        'plot-peak-density.R' 'plot-rt-diff.R' 'plot-purity.R'
        'plot-variants.R' 'plot.R' 'lcmsPlotDataContainer-class.R'
        'creators-chromatograms.R' 'creators-intensity-map.R'
        'creators-peak-density.R' 'creators-rt-diff.R'
        'creators-spectra.R' 'creators-total-ion-current.R'
        'lcmsPlot-class.R' 'app-utils.R' 'app-options.R'
        'app-module-chromatogram.R' 'app-module-peak-density.R'
        'app-module-spectra.R' 'app-module-tic.R' 'app-interface.R'
        'app-launcher.R'
VignetteBuilder: knitr
URL: https://github.com/computational-metabolomics/lcmsPlot
Roxygen: list(markdown = TRUE)
biocViews: Metabolomics, MassSpectrometry
BugReports: https://github.com/computational-metabolomics/lcmsPlot/issues
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
git_url: https://git.bioconductor.org/packages/lcmsPlot
git_branch: devel
git_last_commit: 1a326fb
git_last_commit_date: 2026-06-01
Repository: Bioconductor 3.24
Date/Publication: 2026-07-14
NeedsCompilation: no
Packaged: 2026-07-14 22:36:00 UTC; biocbuild
Author: Ossama Edbali [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0132-8668>),
  Ralf Johannes Maria Weber [aut] (ORCID:
    <https://orcid.org/0000-0002-8796-4771>)
Maintainer: Ossama Edbali <o.edbali@bham.ac.uk>
