#' @importFrom methods show new validObject slot slotNames is as
#' @importFrom stats as.formula setNames
#' @import dplyr
#' @import tibble
#' @import ggplot2
NULL

utils::globalVariables(c(".", ".data"))
