% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/app-options.R
\name{.apply_options}
\alias{.apply_options}
\title{Apply Options-panel choices as \verb{lp_*()} layers to an lcmsPlotClass}
\usage{
.apply_options(obj, opts)
}
\arguments{
\item{obj}{An \code{lcmsPlotClass}.}

\item{opts}{A named \code{list} of options (see \code{\link[=.options_server]{.options_server()}}).}
}
\value{
The (possibly layered) \code{lcmsPlotClass}.
}
\description{
Pure function (no Shiny). Given an \code{lcmsPlotClass} and a list as produced
by \code{\link[=.options_server]{.options_server()}}, appends the corresponding \code{lp_facets},
\code{lp_arrange}, \code{lp_legend}, and \code{lp_labels} layers when their inputs are
non-\code{NULL}. Used by every plot module immediately before \code{lp_get_plot()}.
}
\keyword{internal}
