% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/creators-chromatograms.R
\name{create_chromatograms}
\alias{create_chromatograms}
\alias{create_chromatograms,DBIConnection,data.frame,list,NULL-method}
\alias{create_chromatograms,XcmsRawList,data.frame,list,NULL-method}
\alias{create_chromatograms,XcmsRawList,data.frame,list,ANY-method}
\alias{create_chromatograms,MChromatograms,data.frame,list,NULL-method}
\alias{create_chromatograms,XChromatogram,data.frame,list,NULL-method}
\alias{create_chromatograms,XChromatograms,data.frame,list,NULL-method}
\alias{create_chromatograms,ANY,data.frame,list,NULL-method}
\alias{create_chromatograms,ANY,data.frame,list,character-method}
\alias{create_chromatograms,ANY,data.frame,list,ANY-method}
\title{Create chromatogram data from a data object}
\usage{
create_chromatograms(data_obj, metadata, options, features)

\S4method{create_chromatograms}{DBIConnection,data.frame,list,NULL}(data_obj, metadata, options, features)

\S4method{create_chromatograms}{XcmsRawList,data.frame,list,NULL}(data_obj, metadata, options, features)

\S4method{create_chromatograms}{XcmsRawList,data.frame,list,ANY}(data_obj, metadata, options, features)

\S4method{create_chromatograms}{MChromatograms,data.frame,list,NULL}(data_obj, metadata, options, features)

\S4method{create_chromatograms}{XChromatogram,data.frame,list,NULL}(data_obj, metadata, options, features)

\S4method{create_chromatograms}{XChromatograms,data.frame,list,NULL}(data_obj, metadata, options, features)

\S4method{create_chromatograms}{ANY,data.frame,list,NULL}(data_obj, metadata, options, features)

\S4method{create_chromatograms}{ANY,data.frame,list,character}(data_obj, metadata, options, features)

\S4method{create_chromatograms}{ANY,data.frame,list,ANY}(data_obj, metadata, options, features)
}
\arguments{
\item{data_obj}{The data object (e.g. \code{XCMSnExp}, \code{DBIConnection}, \code{character}).}

\item{metadata}{A \code{tibble} of sample metadata.}

\item{options}{A \code{list} of plot options.}

\item{features}{\code{NULL}, a \code{character} vector of feature IDs, or a
\code{matrix}/\code{tibble} of feature ranges.}
}
\value{
A named \code{list} with elements \code{chromatograms}, \code{mass_traces},
\code{feature_metadata}, and \code{detected_peaks}.
}
\description{
Dispatches to the appropriate implementation based on the type of \code{data_obj}
and \code{features}. Returns a named list with slots to be assigned onto
\code{lcmsPlotDataContainer}.
}
\keyword{internal}
