% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-adapters.R
\name{get_grouped_peaks}
\alias{get_grouped_peaks}
\alias{get_grouped_peaks.default}
\alias{get_grouped_peaks.XCMSnExp}
\alias{get_grouped_peaks.XcmsExperiment}
\alias{get_grouped_peaks.MsExperiment}
\alias{get_grouped_peaks.purityA}
\title{Get the grouped peaks across samples (features) from the data object}
\usage{
get_grouped_peaks(obj)

\method{get_grouped_peaks}{default}(obj)

\method{get_grouped_peaks}{XCMSnExp}(obj)

\method{get_grouped_peaks}{XcmsExperiment}(obj)

\method{get_grouped_peaks}{MsExperiment}(obj)

\method{get_grouped_peaks}{purityA}(obj)
}
\arguments{
\item{obj}{A data object containing or representing samples.}
}
\value{
A \code{tibble} of grouped (feature-level) peaks,
or \code{NULL} if not available.
}
\description{
\code{get_grouped_peaks()} is an internal helper that retrieves feature-level
grouped peaks, i.e., chromatographic peaks aligned across samples.
}
\keyword{internal}
