% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/creators-peak-density.R
\name{create_peak_density}
\alias{create_peak_density}
\alias{create_peak_density,lcmsPlotDataContainer,list-method}
\title{Create an instance of class \code{lcmsPlotDataContainer} from a peak density
dataset.}
\usage{
create_peak_density(obj, options)

\S4method{create_peak_density}{lcmsPlotDataContainer,list}(obj, options)
}
\arguments{
\item{obj}{An instance of class \code{lcmsPlotDataContainer}.}

\item{options}{A \code{list} representing the plot object's options.}
}
\value{
An instance of class \code{lcmsPlotDataContainer} with the created
peak density dataset. The \code{peak_density} slot is a \code{tibble} with columns
\code{rt}, \code{density}, \code{rtmin}, \code{rtmax}, \code{data_type} (\code{"density"} or \code{"rect"}),
\code{mzmin}, \code{mzmax}, \code{metadata_index}, and \code{feature_metadata_id}.
}
\description{
This function creates an \code{lcmsPlotDataContainer} object from
a dataset that contains peak density data for each feature (i.e.,
the kernel density of peak apex RTs across samples for each m/z bin),
mirroring the algorithm used by \code{xcms::plotChromPeakDensity()}.
}
\keyword{internal}
