% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/app-options.R
\name{.na_to_null}
\alias{.na_to_null}
\title{Normalise an NA numeric input to NULL}
\usage{
.na_to_null(x)
}
\description{
Normalise an NA numeric input to NULL
}
\keyword{internal}
