% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/raw-file-reader.R
\docType{class}
\name{XcmsRawReader-class}
\alias{XcmsRawReader-class}
\title{An \code{xcmsRaw}-backed raw MS file reader}
\description{
Wraps an in-memory \code{xcmsRaw} object. No file connection is opened or closed.
}
\section{Slots}{

\describe{
\item{\code{obj}}{An \code{xcmsRaw} object.}
}}

\keyword{internal}
