% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/raw-file-reader.R
\docType{class}
\name{MsRawReader-class}
\alias{MsRawReader-class}
\title{Virtual base class for raw MS file readers}
\description{
\code{MsRawReader} is an abstract S4 class that defines the interface for
reading raw mass spectrometry data files. Concrete subclasses implement
the interface for specific backends (e.g., \code{mzR}, \code{rawrr}).
}
\keyword{internal}
