% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/app-utils.R
\name{.file_ext}
\alias{.file_ext}
\title{Lowercased file extension without the dot}
\usage{
.file_ext(path)
}
\arguments{
\item{path}{A \code{character} vector of file paths.}
}
\value{
A \code{character} vector of the same length, lowercased extensions.
}
\description{
Lowercased file extension without the dot
}
\keyword{internal}
